# ashberry
A tool to search for websites by generating random domains
# install
`pip install ashberry`
# using
```
$ ashberry
Level
> {LEVEL}
Searching...
```
# level
`{LEVEL}` can be:

`10` (`Level.FIRST`)\
`15` (`Level.SECOND`)\
`20` (`Level.THIRD`)

`Level.FIRST`
```
- All lowercase letters used in generation
```
`Level.SECOND`
```
- All lowercase & uppercase used in generation
```
`Level.THIRD`
```
- All lowercase & uppercase letters with digits used in generation